<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Cerrar (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Contraer</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandir</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Desactivar alerta</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%1% de %Ln minuto</numerusform>
            <numerusform>%1% de %Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%1% of %Ln word(s)</source>
        <translation>
            <numerusform>%1% de %Ln palabra</numerusform>
            <numerusform>%1% de %Ln palabras</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln palabra</numerusform>
            <numerusform>%Ln palabras</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progreso diario</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Racha mas larga</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Racha actual</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n día</numerusform>
            <numerusform>%n días</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%1% of daily goal</source>
        <translation>%1% de meta diaria</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Establecer idioma</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sin título %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Solo lectura)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>No se puede guardar «%1».</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Guardar archivo como</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>No se puede sobrescribir «%1».</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Renombrar el archivo</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>No se puede renombrar «%1».</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>¿Recargar archivo?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>¿Recargar el archivo &apos;%1&apos; desde el disco?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Se perderán todos los cambios no guardados.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Al guardar como texto plano se descartarán todos los cambios de formato. ¿Desea continuar?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Archivo modificado</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>El archivo &apos;%1&apos; fue modificado por otro programa.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>¿Desea volver a cargarlo?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Volver a cargar</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Archivo eliminado</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>El archivo %1 ha sido eliminado por otro programa.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>¿Desea guardar o cerrar el archivo?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>No se puede abrir el archivador.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Reemplazar por:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorar mayúsculas y minúsculas</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Solo palabras completas</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expresiones regulares</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Hacia atrás</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Hacia adelante</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Buscar</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Reemplazar</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Reemplazar &amp;todas</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Buscar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Reemplazar</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>¿Reemplazar %n coincidencia?</numerusform>
            <numerusform>¿Reemplazar %n coincidencias?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>No se encontró la frase.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Texto OpenDocument</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>XML plano OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>XML Office</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Texto Enriquecido</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Texto plano</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Todos los archivos</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Todos los archivos soportados</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Revisar la ortografía…</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(No se encontraron sugerencias)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Images(%1)</source>
        <translation>Imágenes(%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma de la aplicación:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie la aplicación para que el cambio de idioma tenga efecto.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Incapaz de abrir el archivo.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <source>General</source>
        <translation>General</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estadísticas</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Ortografía</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Seleccionar diccionario</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>No se puede abrir el archivador.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>El archivador no contiene un diccionario compatible.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Dos o más atajos coinciden. ¿Desea continuar?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>El diccionario «%1» ya existe. ¿Quiere reemplazarlo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Objetivo diario</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutos:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Palabras:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edición</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centrar siempre verticalmente</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Bloquear el cursor de inserción</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Suavizar tipografías</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Sonidos de máquina de escribir</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Comillas tipográficas:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Dobles</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Escenas</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Separador:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>Guardado</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Recordar la posición del cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Número de palabras</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Número de páginas</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Número de párrafos</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Número de caracteres</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caracteres:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Párrafos:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo para contar palabras</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>¿Restablecer a cero el progreso diario actual?</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>¿Borrar el diccionario actual?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Escribir la marca de ordenación de bytes en archivos de texto plano</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Formato por defecto:</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interfaz de usuario</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Mostrar la barra de desplazamiento siempre</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Mostrar la barra superior siempre</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Mostrar la barra inferior siempre</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Restablecer hoy</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Historial</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Recordar historial</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostrar rachas</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progreso mínimo para las rachas:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detectar límites de palabras</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividir entre seis el número de caracteres</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Contar cada letra como una palabra</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmo de conteo de palabras</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Solo iconos</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Solo texto</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Texto al lado de los iconos</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Texto debajo de los iconos</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posición del texto:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Acciones</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Subir</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Bajar</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Añadir separador</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atajo</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Acción</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Revisar la ortografía mientras escribe</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Omitir palabras en MAYÚSCULAS</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Omitir palabras con números</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Diccionario personal</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>No es un archivo RTF soportado.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Alcanzado el final del archivo de forma inesperada.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl + Mayús + Abajo</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Subir escenas</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl + Mayús + Arriba</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Invertir la lista de escenas</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Mayús + F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostrar la lista de escenas (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Ocultar la lista de escenas (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Bajar escenas</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Cambiar el tamaño de la lista de escenas</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestionar sesiones</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>&amp;Sesiones</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renombrar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Cambiar a</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nueva sesión</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplicar sesión</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Renombrar la sesión</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>¿Quiere eliminar la sesión seleccionada?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nombre de la sesión:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>El nombre solicitado ya está en uso.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nueva...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Mayús+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Gestionar...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Mayús+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Restablecer valores predeterminados</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Atajo:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>Reemplazando comillas...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espere un momento</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Revisar la ortografía</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Añadir</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>Omitir &amp;todas</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Cambiar</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>Cambiar t&amp;odas</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>No se encontró en el diccionario:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Cambiar por:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Revisando la ortografía...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Espere un momento</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>¿Continuar comprobación al principio del archivo?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>Finalizó la revisión ortográfica.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Símbolos usados recientemente</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Todos los símbolos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalles</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Insertar</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Bloques</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Secuencias</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Sin imagen</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Mosaico</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrado</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Estirado</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>A escala</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Ampliado</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidad:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posición:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Anchura:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Esquinas de fondo de texto redondeadas</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Radio:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Desenfocar el fondo del texto</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Sombrear el fondo del texto</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Posición vertical:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Márgenes</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Ventana:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Página</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Sangría en la primera línea</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Por encima:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Por debajo:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Editar tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fondo de ventana</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Color:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagen:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> píxeles</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Fondo del texto</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tipo de letra:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Faltas ortográficas:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Interlineado</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Sencillo</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 líneas</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Doble</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Espaciado entre párrafos</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Anchura de tabulación</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Nuevo tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Predeterminado</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Cielos Amargos</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Encantamiento</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Blues Apacible</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Vieja Escuela</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Sueños Espaciales</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Juegos de Espías</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquilidad</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizados</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Borrar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>¿Borrar tema &apos;%1&apos;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temas (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importar tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportar tema</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>¿Quiere eliminar la alarma?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Palabras:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Páginas:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Párrafos:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caracteres:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Establecer tiempo</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Establecer hora</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Tiempo:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alarma</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Nota:</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>No hay ninguna alarma activada</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Alarmas</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nueva</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recientes</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Confirmación</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>¿Quiere cancelar la edición de las alarmas?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>Cargando temas</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>Cargando sonidos</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir archivo</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Acerca de FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Un procesador de textos simple a pantalla completa</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado con licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Iconos del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Usados según la licencia &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caracteres: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Páginas: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Párrafos: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Palabras: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Abriendo %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sin título %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Listar todos los documentos</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Cambiar al documento siguiente</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Cambiar al documento anterior</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Cambiar al primer documento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Cambiar al último documento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Cambiar al documento %1</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>Cargando configuración</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>No se puede escribir en la caché de emergencia.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Advertencia</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter no se cerró correctamente.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>¿Desea restaurarlo desde la caché de emergencia?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Algunos archivos no se pueden abrir.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Algunos archivos se abrieron como solo lectura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&quot;%1&quot; es más reciente que la copia en caché.</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>¿Desea sobrescribir el archivo más reciente?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>¿Guardar cambios?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>¿Guardar cambios al archivo &apos;%1&apos; antes de cerrar?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Tus cambios se perderán si no los guardas.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>No se pueden cargar los sonidos de máquina de escribir.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuevo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>A&amp;brir...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Vol&amp;ver a cargar</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>G&amp;uardar como...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Cambiar nombre...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Guardar &amp;todo</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gestionar sesiones</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nueva sesión</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimir...</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Configuración de pá&amp;gina...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>C&amp;errar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Sali&amp;r</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl + Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Deshacer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Rehacer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>C&amp;ortar</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Pegar</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Pegar sin &amp;formato</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl + Mayús + V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>&amp;Seleccionar todo</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Seleccionar &amp;escena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl + Mayús + A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>&amp;Formato</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>Encabezado</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Encabezado &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Encabezado &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Encabezado &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Encabezado &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Encabezado &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Encabezado &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Negrita</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Cursiva</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Subrayado</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>&amp;Tachado</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl + K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Su&amp;períndice</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl + ^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>Su&amp;bíndice</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl + _</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Alinear a la i&amp;zquierda</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Caracteres: 0</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Centra&amp;r</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl + |</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Alinear a la &amp;derecha</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl + }</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justificar</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl + J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Disminuir sangría</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl + &lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>&amp;Aumentar sangría</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl + &gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>&amp;Escribir de izquierda a derecha</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Escribir de derec&amp;ha a izquierda</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Herramientas</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Buscar...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Buscar &amp;siguiente</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Buscar &amp;anterior</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Reemplazar...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl + R</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Comillas tipográficas</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Actualizar &amp;documento</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Actualizar comillas inteligentes del documento</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Actualizar &amp;selección</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Actualizar comillas inteligentes de la selección</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografía...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Estab&amp;lecer idioma...</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>&amp;Alarmas...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Símb&amp;olos…</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>Progreso &amp;diario</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mo&amp;strar barra de herramientas</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>M&amp;ostrar iconos del menú</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>En&amp;focar el texto</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>&amp;Minimizar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl + M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temas...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencias...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Desactivar foco</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Enfocar una línea</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Enfocar tres líneas</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Párrafo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Enfocar un párrafo</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Mayús+`</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Ayuda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Idioma de la aplicación...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Algunos archivos no son compatibles y no pueden abrirse.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Desactivar</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>Una &amp;línea</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tres líneas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>A&amp;cerca</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Ac&amp;erca de Qt</translation>
    </message>
</context>
</TS>
